@@ -4,5 +4,5 @@ import dataclasses
 @dataclasses.dataclass
 class ReservationResponse:
     token: str
-    pod_name: str
     stream_url: str
+    stream_host: str
