@@ -12,10 +12,21 @@ def is_last_packet(packet: DataPacket, last_sent_packet_number: int) -> bool:
     :return: True if its the last packet to be received
     """
 
-    if packet.get_header(PACKET_NUMBER_HEADER) == last_sent_packet_number:
+    if packet.get_header(PACKET_NUMBER_HEADER, dtype=int) == last_sent_packet_number:
         if packet.get_header(SPLIT_PACKET_HEADER, default=False):
             return packet.get_header(FINAL_SPLIT_PACKET_HEADER, default=False)
         else:
             return True
     else:
         return False
+
+
+def is_last_split(packet: DataPacket) -> bool:
+    """
+    Utility method to determine if the given packet is the last one in a split
+
+    :param packet: current received packet
+    :return: True if its the last packet in split
+    """
+    return not packet.get_header(SPLIT_PACKET_HEADER, default=False, dtype=bool) \
+           or packet.get_header(FINAL_SPLIT_PACKET_HEADER, default=False, dtype=bool)
