@@ -21,7 +21,12 @@ class TranscriptionRequest:
                  fail_url: Optional[str] = None, hotwords: Optional[Union[list, str]] = None,
                  hotwords_weight: Optional[float] = None,
                  transcript_format: TranscriptionResponseFormat = TranscriptionResponseFormat.JSON,
-                 file_duration: Optional[float] = None):
+                 file_duration: Optional[float] = None,
+                 disable_disfluencies: bool = False,
+                 enable_punctuation_capitalization: bool = True,
+                 enable_entities_recognition: bool = True,
+                 enable_numerals_conversion: bool = True,
+                 **kwargs):
         assert file_uid is not None
         assert file_path is not None
         assert model is not None
@@ -37,6 +42,10 @@ class TranscriptionRequest:
         self.hotwords_weight: Optional[float] = None
         self.transcript_format: TranscriptionResponseFormat = transcript_format
         self.file_duration: Optional[float] = file_duration
+        self.disable_disfluencies: bool = disable_disfluencies
+        self.enable_punctuation_capitalization: bool = enable_punctuation_capitalization
+        self.enable_entities_recognition: bool = enable_entities_recognition
+        self.enable_numerals_conversion: bool = enable_numerals_conversion
 
         if isinstance(hotwords, list):
             self.hotwords = hotwords
